@@ -357,7 +357,9 @@ impl CaseHandler<'_> {
                     _ => me.obj,
                 };
                 let prop = if me.computed {
-                    me.prop.map(|prop| self.explode_expr(prop, false))
+                    me.prop.map(|prop| {
+                        self.explode_expr_via_temp_var(None, has_leaping_children, prop, false)
+                    })
                 } else {
                     me.prop
                 };
@@ -374,7 +376,7 @@ impl CaseHandler<'_> {
                 let has_leaping_args = args.iter().any(|t| contains_leap(t));
                 let mut new_args = vec![];
 
-                let callee = match callee {
+                let new_callee = match callee {
                     ExprOrSuper::Expr(e) if e.is_member() => {
                         let me = match *e {
                             Expr::Member(me) => me,
@@ -389,14 +391,21 @@ impl CaseHandler<'_> {
                             // member expression still gets bound to `this` for the call.
 
                             let obj = match me.obj {
-                                ExprOrSuper::Expr(e) => {
-                                    ExprOrSuper::Expr(e.map(|e| self.explode_expr(e, false)))
-                                }
+                                ExprOrSuper::Expr(e) => ExprOrSuper::Expr(e.map(|e| {
+                                    let var = self.make_var();
+                                    self.explode_expr_via_temp_var(
+                                        Some(var),
+                                        has_leaping_children,
+                                        e,
+                                        false,
+                                    )
+                                })),
                                 _ => me.obj,
                             };
 
                             let prop = if me.computed {
-                                me.prop.map(|e| self.explode_expr(e, false))
+                                me.prop
+                                    .map(|e| self.explode_expr_via_temp_var(None, false, e, false))
                             } else {
                                 me.prop
                             };
@@ -425,7 +434,12 @@ impl CaseHandler<'_> {
 
                     ExprOrSuper::Expr(callee) => {
                         let callee = *callee;
-                        let callee = self.explode_expr(callee, false);
+                        let callee = self.explode_expr_via_temp_var(
+                            None,
+                            has_leaping_children,
+                            callee,
+                            false,
+                        );
 
                         let callee = match callee {
                             Expr::Member(..) => {
@@ -463,7 +477,9 @@ impl CaseHandler<'_> {
 
                 if has_leaping_args {
                     new_args.extend(args.into_iter().map(|arg| ExprOrSpread {
-                        expr: arg.expr.map(|e| self.explode_expr(e, false)),
+                        expr: arg.expr.map(|e| {
+                            self.explode_expr_via_temp_var(None, has_leaping_children, e, false)
+                        }),
                         ..arg
                     }));
                 } else {
@@ -472,19 +488,28 @@ impl CaseHandler<'_> {
 
                 finish!(Expr::Call(CallExpr {
                     span,
-                    callee,
+                    callee: new_callee,
                     args: new_args,
                     type_args
                 }))
             }
 
             Expr::New(e) => {
-                let callee = e.callee.map(|e| self.explode_expr(e, false));
+                let callee = e
+                    .callee
+                    .map(|e| self.explode_expr_via_temp_var(None, has_leaping_children, e, false));
                 let args = if let Some(args) = e.args {
                     Some(
                         args.into_iter()
                             .map(|arg| ExprOrSpread {
-                                expr: arg.expr.map(|e| self.explode_expr(e, false)),
+                                expr: arg.expr.map(|e| {
+                                    self.explode_expr_via_temp_var(
+                                        None,
+                                        has_leaping_children,
+                                        e,
+                                        false,
+                                    )
+                                }),
                                 ..arg
                             })
                             .collect(),
@@ -510,11 +535,25 @@ impl CaseHandler<'_> {
                                     | Prop::Getter(_)
                                     | Prop::Shorthand(_) => p,
                                     Prop::KeyValue(p) => Prop::KeyValue(KeyValueProp {
-                                        value: p.value.map(|e| self.explode_expr(e, false)),
+                                        value: p.value.map(|e| {
+                                            self.explode_expr_via_temp_var(
+                                                None,
+                                                has_leaping_children,
+                                                e,
+                                                false,
+                                            )
+                                        }),
                                         ..p
                                     }),
                                     Prop::Assign(p) => Prop::Assign(AssignProp {
-                                        value: p.value.map(|e| self.explode_expr(e, false)),
+                                        value: p.value.map(|e| {
+                                            self.explode_expr_via_temp_var(
+                                                None,
+                                                has_leaping_children,
+                                                e,
+                                                false,
+                                            )
+                                        }),
                                         ..p
                                     }),
                                 }))
@@ -531,12 +570,14 @@ impl CaseHandler<'_> {
             Expr::Array(arr) => {
                 let elems = arr.elems.move_map(|opt| {
                     opt.map(|elem| ExprOrSpread {
-                        expr: elem.expr.map(|e| self.explode_expr(e, false)),
+                        expr: elem.expr.map(|e| {
+                            self.explode_expr_via_temp_var(None, has_leaping_children, e, false)
+                        }),
                         ..elem
                     })
                 });
 
-                ArrayLit { elems, ..arr }.into()
+                finish!(Expr::Array(ArrayLit { elems, ..arr }))
             }
 
             Expr::Seq(e) => {
@@ -554,7 +595,14 @@ impl CaseHandler<'_> {
                 SeqExpr { exprs, ..e }.into()
             }
 
-            Expr::Bin(e) if e.op == op!("&&") || e.op == op!("||") => {
+            Expr::Bin(
+                e
+                @
+                BinExpr {
+                    op: op!("&&") | op!("||"),
+                    ..
+                },
+            ) => {
                 let span = e.span;
                 let op = e.op;
 
@@ -646,8 +694,12 @@ impl CaseHandler<'_> {
 
             Expr::Bin(e) => {
                 let expr = Expr::Bin(BinExpr {
-                    left: e.left.map(|e| self.explode_expr(e, false)),
-                    right: e.right.map(|e| self.explode_expr(e, false)),
+                    left: e.left.map(|e| {
+                        self.explode_expr_via_temp_var(None, has_leaping_children, e, false)
+                    }),
+                    right: e.right.map(|e| {
+                        self.explode_expr_via_temp_var(None, has_leaping_children, e, false)
+                    }),
                     ..e
                 });
 
@@ -1163,6 +1215,7 @@ impl CaseHandler<'_> {
 
             Stmt::Try(s) => {
                 let after = self.loc();
+                let try_entry_idx = self.try_entries.len();
 
                 let TryStmt {
                     mut handler,
@@ -1288,7 +1341,7 @@ impl CaseHandler<'_> {
                     None => {}
                 }
 
-                self.try_entries.push(try_entry);
+                self.try_entries.insert(try_entry_idx, try_entry);
             }
 
             Stmt::While(s) => {
