@@ -1,11 +1,12 @@
 use std::{iter, mem::replace};
 use swc_common::{Mark, Span, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::helper;
+use swc_ecma_transforms_base::{helper, perf::Check};
+use swc_ecma_transforms_macros::fast_path;
 use swc_ecma_utils::{
     contains_ident_ref, contains_this_expr, private_ident, quote_ident, ExprFactory, StmtLike,
 };
-use swc_ecma_visit::{noop_fold_type, Fold, FoldWith};
+use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Node, Visit, VisitWith};
 
 /// `@babel/plugin-transform-async-to-generator`
 ///
@@ -40,6 +41,7 @@ struct Actual {
 }
 
 /// TODO: VisitMut
+#[fast_path(ShouldWork)]
 impl Fold for AsyncToGenerator {
     noop_fold_type!();
 
@@ -78,6 +80,7 @@ impl AsyncToGenerator {
 }
 
 /// TODO: VisitMut
+#[fast_path(ShouldWork)]
 impl Fold for Actual {
     noop_fold_type!();
 
@@ -956,6 +959,37 @@ impl Fold for AsyncFnBodyHandler {
     }
 }
 
+#[derive(Default)]
+struct ShouldWork {
+    found: bool,
+}
+
+impl Visit for ShouldWork {
+    noop_visit_type!();
+
+    fn visit_function(&mut self, f: &Function, _: &dyn Node) {
+        if f.is_async {
+            self.found = true;
+            return;
+        }
+        f.visit_children_with(self);
+    }
+
+    fn visit_arrow_expr(&mut self, f: &ArrowExpr, _: &dyn Node) {
+        if f.is_async {
+            self.found = true;
+            return;
+        }
+        f.visit_children_with(self);
+    }
+}
+
+impl Check for ShouldWork {
+    fn should_handle(&self) -> bool {
+        self.found
+    }
+}
+
 fn extract_callee_of_bind_this(n: &mut CallExpr) -> Option<&mut Expr> {
     if n.args.len() != 1 {
         return None;
